==> opennms-dao-18.0.0-20151015.001454-2-sources.jar: org/opennms/netmgt/dao/hibernate/BridgeBridgeLinkDaoHibernate.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2006-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.dao.hibernate;

import java.util.Date;
import java.util.List;

import org.opennms.netmgt.dao.api.BridgeBridgeLinkDao;
import org.opennms.netmgt.model.BridgeBridgeLink;




public class BridgeBridgeLinkDaoHibernate extends AbstractDaoHibernate<BridgeBridgeLink, Integer> implements BridgeBridgeLinkDao {

    /**
     * <p>
     * Constructor for BridgeBridgeLinkDaoHibernate.
     * </p>
     */
    public BridgeBridgeLinkDaoHibernate() {
        super(BridgeBridgeLink.class);
    }


	@Override
	public List<BridgeBridgeLink> findByNodeId(Integer id) {
		return find("from BridgeBridgeLink rec where rec.node.id = ?", id);
	}

	@Override
	public List<BridgeBridgeLink> findByDesignatedNodeId(Integer id) {
		return find("from BridgeBridgeLink rec where rec.designatedNode.id = ?", id);
	}

	@Override
	public BridgeBridgeLink getByNodeIdBridgePort(Integer id, Integer port) {
		return findUnique("from BridgeBridgeLink rec where rec.node.id = ?  and rec.bridgePort = ?", id,port);
	}

	@Override
	public BridgeBridgeLink getByNodeIdBridgePortIfIndex(Integer id, Integer ifindex) {
		return findUnique("from BridgeBridgeLink rec where rec.node.id = ?  and rec.bridgePortIfIndex = ?", id,ifindex);
	}

	@Override
	public BridgeBridgeLink getByDesignatedNodeIdBridgePort(Integer id, Integer port) {
		return findUnique("from BridgeBridgeLink rec where rec.designatedNode.id = ?  and rec.designatedBridgePort = ?", id,port);
	}

	@Override
	public BridgeBridgeLink getByDesignatedNodeIdBridgePortIfIndex(Integer id, Integer ifindex) {
		return findUnique("from BridgeBridgeLink rec where rec.designatedNode.id = ?  and rec.designatedBridgePortIfIndex = ?", id,ifindex);
	}

	@Override
	public void deleteByNodeIdOlderThen(Integer nodeId, Date now) {
		for (BridgeBridgeLink elem: find("from BridgeBridgeLink rec where rec.node.id = ? and rec.bridgeBridgeLinkLastPollTime < ?",nodeId,now)) {
			delete(elem);
		}
	}

	@Override
	public void deleteByDesignatedNodeIdOlderThen(Integer nodeId, Date now) {
		for (BridgeBridgeLink elem: find("from BridgeBridgeLink rec where rec.designatedNode.id = ? and rec.bridgeBridgeLinkLastPollTime < ?",nodeId,now)) {
			delete(elem);
		}
	}





}

==> opennms-dao-20.0.0-20170118.203738-54-sources.jar: org/opennms/netmgt/dao/hibernate/BridgeBridgeLinkDaoHibernate.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2006-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.dao.hibernate;

import java.util.Date;
import java.util.List;

import org.opennms.netmgt.dao.api.BridgeBridgeLinkDao;
import org.opennms.netmgt.model.BridgeBridgeLink;




public class BridgeBridgeLinkDaoHibernate extends AbstractDaoHibernate<BridgeBridgeLink, Integer> implements BridgeBridgeLinkDao {

    /**
     * <p>
     * Constructor for BridgeBridgeLinkDaoHibernate.
     * </p>
     */
    public BridgeBridgeLinkDaoHibernate() {
        super(BridgeBridgeLink.class);
    }


	@Override
	public List<BridgeBridgeLink> findByNodeId(Integer id) {
		return find("from BridgeBridgeLink rec where rec.node.id = ?", id);
	}

	@Override
	public List<BridgeBridgeLink> findByDesignatedNodeId(Integer id) {
		return find("from BridgeBridgeLink rec where rec.designatedNode.id = ?", id);
	}

	@Override
	public BridgeBridgeLink getByNodeIdBridgePort(Integer id, Integer port) {
		return findUnique("from BridgeBridgeLink rec where rec.node.id = ?  and rec.bridgePort = ?", id,port);
	}

	@Override
	public BridgeBridgeLink getByNodeIdBridgePortIfIndex(Integer id, Integer ifindex) {
		return findUnique("from BridgeBridgeLink rec where rec.node.id = ?  and rec.bridgePortIfIndex = ?", id,ifindex);
	}

	@Override
	public BridgeBridgeLink getByDesignatedNodeIdBridgePort(Integer id, Integer port) {
		return findUnique("from BridgeBridgeLink rec where rec.designatedNode.id = ?  and rec.designatedBridgePort = ?", id,port);
	}

	@Override
	public BridgeBridgeLink getByDesignatedNodeIdBridgePortIfIndex(Integer id, Integer ifindex) {
		return findUnique("from BridgeBridgeLink rec where rec.designatedNode.id = ?  and rec.designatedBridgePortIfIndex = ?", id,ifindex);
	}

	@Override
	public void deleteByNodeIdOlderThen(Integer nodeId, Date now) {
		for (BridgeBridgeLink elem: find("from BridgeBridgeLink rec where rec.node.id = ? and rec.bridgeBridgeLinkLastPollTime < ?",nodeId,now)) {
			delete(elem);
		}
	}

	@Override
	public void deleteByDesignatedNodeIdOlderThen(Integer nodeId, Date now) {
		for (BridgeBridgeLink elem: find("from BridgeBridgeLink rec where rec.designatedNode.id = ? and rec.bridgeBridgeLinkLastPollTime < ?",nodeId,now)) {
			delete(elem);
		}
	}

        @Override
        public void deleteByNodeId(Integer nodeId) {
                for (BridgeBridgeLink elem: find("from BridgeBridgeLink rec where rec.node.id = ? ",nodeId)) {
                        delete(elem);
                }
        }

        @Override
        public void deleteByDesignatedNodeId(Integer nodeId) {
                for (BridgeBridgeLink elem: find("from BridgeBridgeLink rec where rec.designatedNode.id = ? ",nodeId)) {
                        delete(elem);
                }
        }




}
